@@ -4,7 +4,8 @@ from threading import RLock, Thread, current_thread
 from typing import Any, Dict, List, Optional, Tuple, Union
 from urllib.parse import unquote_plus, urlparse
 
-from websocket import ABNF, STATUS_NORMAL, WebSocketApp, enableTrace  # type: ignore[import]
+from certifi import where as certify_where
+from websocket import ABNF, STATUS_NORMAL, WebSocketApp, enableTrace  # type: ignore[attr-defined,import]
 
 from streamlink.logger import TRACE, root as rootlogger
 from streamlink.session import Streamlink
@@ -39,7 +40,7 @@ class WebsocketClient(Thread):
         suppress_origin: bool = False,
         ping_interval: Union[int, float] = 0,
         ping_timeout: Optional[Union[int, float]] = None,
-        ping_payload: str = ""
+        ping_payload: str = "",
     ):
         if rootlogger.level <= TRACE:
             enableTrace(True, log)
@@ -47,9 +48,9 @@ class WebsocketClient(Thread):
         if not header:
             header = []
         elif isinstance(header, dict):
-            header = [f"{str(k)}: {str(v)}" for k, v in header.items()]
+            header = [f"{k!s}: {v!s}" for k, v in header.items()]
         if not any(True for h in header if h.startswith("User-Agent: ")):
-            header.append(f"User-Agent: {str(session.http.headers['User-Agent'])}")
+            header.append(f"User-Agent: {session.http.headers['User-Agent']!s}")
 
         proxy_options: Dict[str, Any] = {}
         http_proxy: Optional[str] = session.get_option("http-proxy")
@@ -65,6 +66,10 @@ class WebsocketClient(Thread):
         self._reconnect = False
         self._reconnect_lock = RLock()
 
+        if not sslopt:  # pragma: no cover
+            sslopt = {}
+        sslopt.setdefault("ca_certs", certify_where())
+
         self.session = session
         self._ws_init(url, subprotocols, header, cookie)
         self._ws_rundata = dict(
@@ -76,13 +81,13 @@ class WebsocketClient(Thread):
             ping_interval=ping_interval,
             ping_timeout=ping_timeout,
             ping_payload=ping_payload,
-            **proxy_options
+            **proxy_options,
         )
 
         self._id += 1
         super().__init__(
             name=f"Thread-{self.__class__.__name__}-{self._id}",
-            daemon=True
+            daemon=True,
         )
 
     def _ws_init(self, url, subprotocols, header, cookie):
@@ -98,7 +103,7 @@ class WebsocketClient(Thread):
             on_pong=self.on_pong,
             on_message=self.on_message,
             on_cont_message=self.on_cont_message,
-            on_data=self.on_data
+            on_data=self.on_data,
         )
 
     def run(self) -> None:
@@ -119,7 +124,7 @@ class WebsocketClient(Thread):
         subprotocols: Optional[List[str]] = None,
         header: Optional[Union[List, Dict]] = None,
         cookie: Optional[str] = None,
-        closeopts: Optional[Dict] = None
+        closeopts: Optional[Dict] = None,
     ) -> None:
         with self._reconnect_lock:
             # ws connection is not active (anymore)
@@ -132,11 +137,11 @@ class WebsocketClient(Thread):
                 url=self.ws.url if url is None else url,
                 subprotocols=self.ws.subprotocols if subprotocols is None else subprotocols,
                 header=self.ws.header if header is None else header,
-                cookie=self.ws.cookie if cookie is None else cookie
+                cookie=self.ws.cookie if cookie is None else cookie,
             )
 
     def close(self, status: int = STATUS_NORMAL, reason: Union[str, bytes] = "", timeout: int = 3) -> None:
-        if type(reason) is str:
+        if isinstance(reason, str):
             reason = bytes(reason, encoding="utf-8")
         self.ws.close(status=status, reason=reason, timeout=timeout)
         if self.is_alive() and current_thread() is not self:
