@@ -138,7 +138,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
             custom=None,
         )
 
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)], end=True),
         ], streamoptions={"disable_ads": True, "low_latency": False})
 
@@ -156,7 +156,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
             custom=None,
         )
 
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)], end=True),
         ], streamoptions={"disable_ads": True, "low_latency": False})
 
@@ -174,7 +174,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
             custom=None,
         )
 
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)], end=True),
         ], streamoptions={"disable_ads": True, "low_latency": False})
 
@@ -192,7 +192,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
             custom={"X-TV-TWITCH-AD-URL": "/"},
         )
 
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)], end=True),
         ], streamoptions={"disable_ads": True, "low_latency": False})
 
@@ -204,7 +204,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
     @patch("streamlink.plugins.twitch.log")
     def test_hls_disable_ads_has_preroll(self, mock_log):
         daterange = TagDateRangeAd(duration=4)
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)]),
             Playlist(2, [daterange, Segment(2), Segment(3)]),
             Playlist(4, [Segment(4), Segment(5)], end=True),
@@ -222,7 +222,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
     @patch("streamlink.plugins.twitch.log")
     def test_hls_disable_ads_has_midstream(self, mock_log):
         daterange = TagDateRangeAd(start=DATETIME_BASE + timedelta(seconds=2), duration=2)
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [Segment(0), Segment(1)]),
             Playlist(2, [daterange, Segment(2), Segment(3)]),
             Playlist(4, [Segment(4), Segment(5)], end=True),
@@ -239,7 +239,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
     @patch("streamlink.plugins.twitch.log")
     def test_hls_no_disable_ads_has_preroll(self, mock_log):
         daterange = TagDateRangeAd(duration=2)
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1)]),
             Playlist(2, [Segment(2), Segment(3)], end=True),
         ], streamoptions={"disable_ads": False, "low_latency": False})
@@ -252,7 +252,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
 
     @patch("streamlink.plugins.twitch.log")
     def test_hls_low_latency_has_prefetch(self, mock_log):
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [Segment(0), Segment(1), Segment(2), Segment(3), SegmentPrefetch(4), SegmentPrefetch(5)]),
             Playlist(4, [Segment(4), Segment(5), Segment(6), Segment(7), SegmentPrefetch(8), SegmentPrefetch(9)], end=True),
         ], streamoptions={"disable_ads": False, "low_latency": True})
@@ -271,7 +271,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
 
     @patch("streamlink.plugins.twitch.log")
     def test_hls_no_low_latency_has_prefetch(self, mock_log):
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [Segment(0), Segment(1), Segment(2), Segment(3), SegmentPrefetch(4), SegmentPrefetch(5)]),
             Playlist(4, [Segment(4), Segment(5), Segment(6), Segment(7), SegmentPrefetch(8), SegmentPrefetch(9)], end=True),
         ], streamoptions={"disable_ads": False, "low_latency": False})
@@ -306,7 +306,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
     @patch("streamlink.plugins.twitch.log")
     def test_hls_low_latency_has_prefetch_has_preroll(self, mock_log):
         daterange = TagDateRangeAd(duration=4)
-        thread, segments = self.subject([
+        segments = self.subject([
             Playlist(0, [daterange, Segment(0), Segment(1), Segment(2), Segment(3)]),
             Playlist(4, [Segment(4), Segment(5), Segment(6), Segment(7), SegmentPrefetch(8), SegmentPrefetch(9)], end=True),
         ], streamoptions={"disable_ads": False, "low_latency": True})
@@ -344,7 +344,7 @@ class TestTwitchHLSStream(TestMixinStreamHLS, unittest.TestCase):
             TagDateRangeAd(start=DATETIME_BASE + timedelta(seconds=3), duration=4),
         ]
         # noinspection PyTypeChecker
-        thread, segments = self.subject([
+        segments = self.subject([
             # regular stream data with prefetch segments
             Playlist(0, [Seg(0), Seg(1, duration=0.5), Pre(2), Pre(3)]),
             # three prefetch segments, one regular (2) and two ads (3 and 4)
